@@ -7,7 +7,7 @@
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-#    Copyright (c) 2007-2010 Dominique Dumont.
+#    Copyright (c) 2007-2011 Dominique Dumont.
 #
 #    This file is part of Config-Model-Itself.
 #
@@ -28,12 +28,28 @@
 [
     [
         name => "Itself::Class",
+        author => 'Dominique Dumont',
+        copyright => '2007-2011 Dominique Dumont.',
+        license => 'LGPL-2',
 
         class_description =>
-          "Configuration class. This class will contain elements",
+          "Configuration class. This class represents a node of a configuration tree.",
 
         'element' => [
 
+            [qw/class_description license/] => {
+                type       => 'leaf',
+                value_type => 'string',
+            },
+
+            [qw/author copyright/] => {
+                type  => 'list',
+                cargo => {
+                    type       => 'leaf',
+                    value_type => 'uniline',
+                }
+            },
+
             'element' => {
                 type       => 'hash',
                 level      => 'important',
@@ -60,11 +76,6 @@
                 refer_to   => '- element',
             },
 
-            'class_description' => {
-                type       => 'leaf',
-                value_type => 'string',
-            },
-
             [qw/write_config_dir read_config_dir/] => {
                 type       => 'leaf',
                 value_type => 'uniline',
@@ -104,7 +115,7 @@
             element => "Specify the elements names of this configuration class.",
             include => "Include the specification of another class into this class.",
             include_after => "insert the included elements after a specific element",
-            class_description => "Explain the purpose of this configuration class",
+            class_description => "Explain the purpose of this configuration class. This description will be re-used to generate the documentation of your configuration class",
             read_config => "Specify the Perl class(es) and function(s) used to read configuration data. The specified function will be tried in sequence to get configuration data. ",
             write_config => "Specify the Perl class and function used to write configuration data.",
             generated_by => "When set, this class was generated by some program. You should not edit it as your modification may be clobbered later on",
